@@ -8,36 +8,33 @@ fn main() {
         .version("0.2")
         .author("Zhenbo Li")
         .about("Creates a single-source-file version of a Cargo package.")
-        .arg("-i, --input=[PATH] 'REQUIRED. Path to a cargo directory' ")
-        .arg("-o, --output=[FILE] 'If not specified, result would be written to STDIN'")
-        .arg("-b --binary=[NAME] 'If multiple [[bin]] defined in Cargo.toml, this field is required'")
+        .args_from_usage("-i, --input=[PATH] 'REQUIRED. Path to a cargo directory' ")
+        .args_from_usage("-o, --output=[FILE] 'If not specified, result would be written to STDIN'")
+        .args_from_usage("-b --binary=[NAME] 'If multiple [[bin]] defined in Cargo.toml, this field is required'")
         .get_matches();
 
 
-    let path:String = match matches.value_of_t("input") {
-        Err(_)       => {
+    let path: String = match matches.value_of("input") {
+        None => {
             eprintln!("Error! Input path have to be specified");
             process::exit(1);
         }
-        Ok(v) => v
+        Some(v) => String::from(v)
     };
-    // eprintln!("Input path = {}", path);
 
-    let binary_selected = match matches.value_of_t("binary") {
-        Err(_)       => {
-            None
-        }
-        Ok(v) => Some(v)
+    let binary_selected = match matches.value_of("binary") {
+        None => None,
+        Some(v) => Some(String::from(v))
     };
 
     let code = rust_bundler_cp::bundle_specific_binary(path, binary_selected);
 
-    match matches.value_of_t("output") {
-        Err(_)  => {
+    match matches.value_of("output") {
+        None => {
             println!("{}", code);
         }
-        Ok(v) => {
-            let v:String = v;
+        Some(v) => {
+            let v: String = String::from(v);
             std::fs::write(&v, code).expect("Unable to write file");
             eprintln!("Bundled rust code written to: {}", &v);
         }
